@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/frame.cpp   3.0.5   edited Apr 15 11:25 $
+** $Id: qt/frame.cpp   3.1.2   edited Nov 8 10:35 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -14,7 +14,7 @@
 #include <qpopupmenu.h>
 #include <qmenubar.h>
 #include <qaccel.h>
-#include <qsplitter.h>
+#include <qhbox.h>
 #include <qlistbox.h>
 #include <qpainter.h>
 #include <qwidgetstack.h>
@@ -22,6 +22,7 @@
 #include <qaction.h>
 #include <qsignalmapper.h>
 #include <qdict.h>
+#include <qdir.h>
 #include <qtextcodec.h>
 #include <stdlib.h>
 
@@ -30,10 +31,8 @@ static QTranslator *qt_translator = 0;
 
 class CategoryItem : public QListBoxItem {
 public:
-    CategoryItem( QListBox *parent, QWidget *widget,
-		  const QPixmap &p, const QString &name, int id );
-    CategoryItem(QListBox *parent, QWidget *widget,
-		  const QPixmap &p1, const QPixmap &p2, const QString &name, int id );
+    CategoryItem( QListBox *parent, QWidget *widget, const QPixmap &p1,
+		  const QPixmap &p2, const QString &name, int id );
     virtual QString key( int, bool ) const;
     virtual int height( const QListBox * ) const;
     virtual int width( const QListBox * )  const;
@@ -50,30 +49,15 @@ private:
     QPixmap pm_Sel;
 };
 
-CategoryItem::CategoryItem( QListBox *parent, QWidget *widget,
-			    const QPixmap &p, const QString &name, int id )
-    : QListBoxItem( parent ),
-      _id( id ),
-      _widget( widget ),
-      pm_Unsel( p ),
-      pm_Sel( p )
-{
-    setText( name );
-}
-
-CategoryItem::CategoryItem( QListBox * parent, QWidget *widget, const QPixmap &p1, const QPixmap &p2,
+CategoryItem::CategoryItem( QListBox * parent, QWidget *widget,
+			    const QPixmap &p1, const QPixmap &p2,
 			    const QString &name, int id )
-    : QListBoxItem( parent ),
-      _id( id),
-      _widget( widget ),
-      pm_Unsel( p1 ),
+    : QListBoxItem( parent ), _id( id ), _widget( widget ), pm_Unsel( p1 ),
       pm_Sel( p2 )
 {
     setText( name );
 }
 
-
-
 QString CategoryItem::key( int, bool ) const
 {
     QString tmp;
@@ -148,46 +132,38 @@ Frame::Frame( QWidget *parent, const char *name )
     mainMenu->insertItem( tr( "St&yle" ), styleMenu );
 
     // category chooser
-    QSplitter *splitter = new QSplitter( this );
-    categories = new QListBox( splitter );
+    hbox = new QHBox( this );
+    hbox->setMargin( 11 );
+    hbox->setSpacing( 6 );
+    categories = new QListBox( hbox );
     QFont f = categories->font();
     f.setWeight( QFont::Bold );
     categories->setFont( f );
+    categories->setHScrollBarMode( QScrollView::AlwaysOff );
 
     connect( categories, SIGNAL( clicked( QListBoxItem *) ),
-                   	     SLOT( clickedCategory( QListBoxItem *) ) );
+	     SLOT( clickedCategory( QListBoxItem *) ) );
+    connect( categories, SIGNAL( returnPressed( QListBoxItem *) ),
+	     SLOT( clickedCategory( QListBoxItem *) ) );
 
     // stack for the demo widgets
-    stack = new QWidgetStack( splitter );
+    stack = new QWidgetStack( hbox );
+    stack->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
 
-    setCentralWidget( splitter );
-}
-
-void Frame::addCategory( QWidget *w, const QPixmap &p, const QString &n )
-{
-    int i = categories->count();
-    stack->addWidget( w, i );
-    CategoryItem *item = new CategoryItem( categories, w, p, n, i );
-    if ( !stack->visibleWidget() ) {
-	categories->setCurrentItem( item );
-	clickedCategory( item );
-    }
-    if ( i < 3 && categories->height() < 3 * item->height( categories ) )
-	categories->setMinimumHeight( 3 * item->height( categories ) );
+    setCentralWidget( hbox );
 }
 
 void Frame::addCategory( QWidget *w, const QPixmap &p1, const QPixmap &p2, const QString &n )
 {
     int i = categories->count();
-    if(w)
+    if ( w )
 	stack->addWidget( w, i );
     CategoryItem *item = new CategoryItem( categories, w, p1, p2, n, i );
+    categories->setFixedWidth( categories->sizeHint().width() );
     if ( !stack->visibleWidget() ) {
 	categories->setCurrentItem( item );
 	clickedCategory( item );
     }
-    if ( i < 3 && categories->height() < 3 * item->height( categories ) )
-	categories->setMinimumHeight( 3 * item->height( categories ) );
 }
 
 void Frame::setStyle( const QString& style )
@@ -211,7 +187,7 @@ void Frame::clickedCategory( QListBoxItem *item )
 		qDebug("Lazy creation of %s failed", item->text().latin1());
 	    }
 	}
-	stack->raiseWidget( c->widget() );    
+	stack->raiseWidget( c->widget() );
     }
 }
 
@@ -224,15 +200,12 @@ void Frame::updateTranslators()
 	qApp->installTranslator( translator );
     }
 
-    QString QTDIR = getenv( "QTDIR" );
-
-    qt_translator->load( QString( "qt_%1" ).arg( QTextCodec::locale() ), QTDIR + "/translations" );
+    QString base = QString( qInstallPathData() ) + "/translations";
+    qt_translator->load( QString( "qt_%1" ).arg( QTextCodec::locale() ), base );
     translator->load( QString( "translations/demo_%1" ).arg( QTextCodec::locale() ) );
 }
 
-
-void
-Frame::setCurrentCategory( QWidget *w )
+void Frame::setCurrentCategory( QWidget *w )
 {
     for(int i = 0; i < (int)categories->count(); i++) {
 	QListBoxItem *item = categories->item(i);
@@ -244,12 +217,19 @@ Frame::setCurrentCategory( QWidget *w )
     }
 }
 
-
-void
-Frame::setCurrentCategory( const QString &s )
+void Frame::setCurrentCategory( const QString &s )
 {
-    if(QListBoxItem *i = categories->findItem(s)) {
+    QListBoxItem *i = categories->findItem( s );
+    if ( i ) {
 	categories->setCurrentItem( i );
 	clickedCategory( i );
     }
 }
+
+bool Frame::event( QEvent *e )
+{
+    if ( e->type() == QEvent::LocaleChange )
+	updateTranslators();
+
+    return QMainWindow::event( e );
+}
