@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/glgear.cpp   3.0.5   edited Oct 12 2001 $
+** $Id: qt/glgear.cpp   3.1.2   edited Nov 8 10:35 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -151,8 +151,6 @@ static void gear( GLfloat inner_radius, GLfloat outer_radius, GLfloat width,
 
 void GLGear::draw()
 {
-    glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
-
     glPushMatrix();
     glRotatef( view_rotx, 1.0, 0.0, 0.0 );
     glRotatef( view_roty, 0.0, 1.0, 0.0 );
@@ -244,10 +242,26 @@ void GLGear::resizeGL( int width, int height )
 
 void GLGear::paintGL()
 {
+    glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
     glPushMatrix();
     transform();
     draw();
+    drawText();
+    
+    glPushAttrib( GL_LIGHTING_BIT | GL_TEXTURE_BIT );
+    glDisable( GL_LIGHTING );
+    glDisable( GL_TEXTURE_2D );
+    qglColor( green );
+    glLineWidth( 1.0 );
+    glBegin( GL_LINES );
+    {
+	glVertex3f( 0.0, 0.0, 0.0 );
+	glVertex3f( 2.98, 2.98, 2.98 );
+    }
+    glEnd();
+    renderText( 3.0, 3.0, 3.0, "Gears", QFont( "helvetica", 12, QFont::Bold, TRUE ) );
     glPopMatrix();
+    glPopAttrib();
 }
 
 void GLGear::animate()
