@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/showimg.cpp   3.0.5   edited Oct 12 2001 $
+** $Id: qt/showimg.cpp   3.1.2   edited Jan 22 15:28 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -145,27 +145,27 @@ void ImageViewer::doOption(int item)
     int ocf = conversion_flags;
 
     if ( item == ac ) {
-	conversion_flags = conversion_flags & ~ColorMode_Mask | AutoColor;
+	conversion_flags = ( conversion_flags & ~ColorMode_Mask ) | AutoColor;
     } else if ( item == co ) {
-	conversion_flags = conversion_flags & ~ColorMode_Mask | ColorOnly;
+	conversion_flags = ( conversion_flags & ~ColorMode_Mask ) | ColorOnly;
     } else if ( item == mo ) {
-	conversion_flags = conversion_flags & ~ColorMode_Mask | MonoOnly;
+	conversion_flags = ( conversion_flags & ~ColorMode_Mask ) | MonoOnly;
     } else if ( item == fd ) {
-	conversion_flags = conversion_flags & ~Dither_Mask | DiffuseDither;
+	conversion_flags = ( conversion_flags & ~Dither_Mask ) | DiffuseDither;
     } else if ( item == bd ) {
-	conversion_flags = conversion_flags & ~Dither_Mask | OrderedDither;
+	conversion_flags = ( conversion_flags & ~Dither_Mask ) | OrderedDither;
     } else if ( item == td ) {
-	conversion_flags = conversion_flags & ~Dither_Mask | ThresholdDither;
+	conversion_flags = ( conversion_flags & ~Dither_Mask ) | ThresholdDither;
     } else if ( item == ta ) {
-	conversion_flags = conversion_flags & ~AlphaDither_Mask | ThresholdAlphaDither;
+	conversion_flags = ( conversion_flags & ~AlphaDither_Mask ) | ThresholdAlphaDither;
     } else if ( item == fa ) {
-	conversion_flags = conversion_flags & ~AlphaDither_Mask | DiffuseAlphaDither;
+	conversion_flags = ( conversion_flags & ~AlphaDither_Mask ) | DiffuseAlphaDither;
     } else if ( item == ba ) {
-	conversion_flags = conversion_flags & ~AlphaDither_Mask | OrderedAlphaDither;
+	conversion_flags = ( conversion_flags & ~AlphaDither_Mask ) | OrderedAlphaDither;
     } else if ( item == ad ) {
-	conversion_flags = conversion_flags & ~DitherMode_Mask | PreferDither;
+	conversion_flags = ( conversion_flags & ~DitherMode_Mask ) | PreferDither;
     } else if ( item == dd ) {
-	conversion_flags = conversion_flags & ~DitherMode_Mask | AvoidDither;
+	conversion_flags = ( conversion_flags & ~DitherMode_Mask ) | AvoidDither;
     }
 
     if ( ocf != conversion_flags ) {
@@ -227,7 +227,7 @@ void ImageViewer::setMenuItemFlags()
 void ImageViewer::updateStatus()
 {
     if ( pm.size() == QSize( 0, 0 ) ) {
-	if ( filename )
+	if ( !filename.isEmpty() )
 	    status->setText("Could not load image");
 	else
 	    status->setText("No image - select Open from File menu.");
@@ -323,7 +323,9 @@ void ImageViewer::newWindow()
 */
 void ImageViewer::openFile()
 {
-    QString newfilename = QFileDialog::getOpenFileName();
+    QString newfilename = QFileDialog::getOpenFileName( QString::null,
+							QString::null,
+							this );
     if ( !newfilename.isEmpty() ) {
 	loadImage( newfilename ) ;
 	repaint();			// show image in widget
@@ -339,11 +341,11 @@ void ImageViewer::openFile()
   Returns TRUE if the image was successfully loaded.
 */
 
-bool ImageViewer::loadImage( const char *fileName )
+bool ImageViewer::loadImage( const QString& fileName )
 {
     filename = fileName;
     bool ok = FALSE;
-    if ( filename ) {
+    if ( !filename.isEmpty() ) {
 	QApplication::setOverrideCursor( waitCursor ); // this might take time
 	ok = image.load(filename, 0);
 	pickx = -1;
