@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/metal.cpp   3.0.5   edited Dec 4 2001 $
+** $Id: qt/metal.cpp   3.1.2   edited Nov 8 10:35 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -30,7 +30,7 @@
 
 
 /////////////////////////////////////////////////////////
-#include "stonedark.xpm"
+//#include "stonedark.xpm"
 #include "stone1.xpm"
 #include "marble.xpm"
 ///////////////////////////////////////////////////////
