@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/main.cpp   3.0.5   edited Jun 15 20:49 $
+** $Id: qt/main.cpp   3.1.2   edited Nov 22 16:52 $
 **
 ** Definition of ________ class.
 **
@@ -48,20 +48,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-static bool createDir(const QString& fullPath)
-{
-    QDir dirTmp;
-    QString pathComponent, tmpPath;
-    QStringList hierarchy = QStringList::split(QString(Option::dir_sep), fullPath);
-    for(QStringList::Iterator it = hierarchy.begin(); it != hierarchy.end(); ++it) {
-	pathComponent = *it + QDir::separator();
-	tmpPath += pathComponent;
-	if(!dirTmp.mkdir(tmpPath))
-	    return FALSE;
-    }
-    return TRUE;
-}
-
 // for Borland, main is defined to qMain which breaks qmake
 #undef main
 
@@ -73,6 +59,14 @@ int main(int argc, char **argv)
 
     QDir sunworkshop42workaround = QDir::current();
     QString oldpwd = sunworkshop42workaround.currentDirPath();
+    Option::output_dir = oldpwd; //for now this is the output dir
+#ifdef Q_WS_WIN
+    if ( !(Option::output_dir.length() == 3 && Option::output_dir[0].isLetter() && Option::output_dir.endsWith(":/") ) )
+#endif
+    {
+	if(Option::output_dir.right(1) != QString(QChar(QDir::separator())))
+	    Option::output_dir += QDir::separator();
+    }
     QMakeProject proj;
     int exit_val = 0;
     QStringList files;
@@ -121,46 +115,15 @@ int main(int argc, char **argv)
 		      Option::qmake_mode == Option::QMAKE_GENERATE_PROJECT)) {
 	    //open output
 	    if(!(Option::output.state() & IO_Open)) {
-		QString default_makefile;
-		if(Option::qmake_mode == Option::QMAKE_GENERATE_MAKEFILE)
-		    default_makefile = proj.first("QMAKE_MAKEFILE");
-		if(default_makefile.isEmpty()) {
-		    default_makefile = mkfile->defaultMakefile();
-		    proj.variables()["QMAKE_MAKEFILE"].append(default_makefile);
-		}
-		if(Option::output.name().isEmpty()) {
-		    if(default_makefile.findRev(Option::dir_sep) != -1) 
-			createDir(default_makefile.left(
-			    default_makefile.findRev(Option::dir_sep)));
-		    Option::output.setName(default_makefile);
-		}
-		if(Option::output.name().isEmpty() || Option::output.name() == "-") {
+		if(Option::output.name() == "-") {
 		    Option::output.setName("");
+		    Option::output_dir = QDir::currentDirPath();
 		    Option::output.open(IO_WriteOnly | IO_Translate, stdout);
 		    using_stdout = TRUE;
 		} else {
-		    if(Option::qmake_mode == Option::QMAKE_GENERATE_MAKEFILE &&
-		       QDir::isRelativePath(Option::output.name()) && 
-		       proj.first("TEMPLATE").find(QRegExp("^vc.*")) != -1) {
-			QString ofile;
-			ofile = Option::output.name();
-			int slashfind = ofile.findRev('\\');
-			if (slashfind == -1)
-			    ofile = ofile.replace(QRegExp("-"), "_");
-			else { 
-			    int hypenfind = ofile.find('-', slashfind);
-			    while (hypenfind != -1 && slashfind < hypenfind) {
-				ofile = ofile.replace(hypenfind, 1, "_");
-				hypenfind = ofile.find('-', hypenfind + 1);
-			    }
-			}
-			Option::output.setName(Option::fixPathToLocalOS(oldpwd + Option::dir_sep + ofile));
-		    }
-
-		    QFileInfo fi(Option::output);
-		    Option::output_dir = Option::fixPathToTargetOS(
-			    (fi.isSymLink() ? fi.readLink() : fi.dirPath()) );
-		    if(!Option::output.open(IO_WriteOnly | IO_Translate)) {
+		    if(Option::output.name().isEmpty() && Option::qmake_mode == Option::QMAKE_GENERATE_MAKEFILE)
+			Option::output.setName(proj.first("QMAKE_MAKEFILE"));
+		    if(!mkfile->openOutput(Option::output)) {
 			fprintf(stderr, "Failure to open file: %s\n",
 				Option::output.name().isEmpty() ? "(stdout)" : Option::output.name().latin1());
 			return 5;
