@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id:  qt/qpixmap_x11.cpp   3.0.5   edited Jun 11 16:00 $
+** $Id: qt/qpixmap_x11.cpp   3.1.2   edited Feb 19 18:10 $
 **
 ** Implementation of QPixmap class for X11
 **
 ** Created : 940501
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -139,7 +139,7 @@ static bool qt_create_mitshm_buffer( const QPaintDevice* dev, int w, int h )
     if ( ok ) {
 	xshmimg->data = (char*)shmat( xshminfo.shmid, 0, 0 );
 	xshminfo.shmaddr = xshmimg->data;
-	ok = xshminfo.shmaddr != 0;
+	ok = ( xshminfo.shmaddr != (char*)-1 );
     }
     xshminfo.readOnly = FALSE;
     if ( ok )
@@ -262,6 +262,14 @@ static void build_scale_table( uint **table, uint nBits )
 static int defaultScreen = -1;
 
 extern bool qt_use_xrender; // defined in qapplication_x11.cpp
+extern bool qt_has_xft;     // defined in qfont_x11.cpp
+
+#ifndef QT_NO_XFTFREETYPE
+#ifndef QT_XFT2
+// Xft1 doesn't have XftDrawCreateAlpha, so we fake it in qtaddons_x11.cpp
+extern "C" XftDraw *XftDrawCreateAlpha( Display *, Qt::HANDLE, int );
+#endif // QT_XFT2
+#endif // QT_NO_XFTFREETYPE
 
 /*****************************************************************************
   QPixmap member functions
@@ -279,24 +287,12 @@ void QPixmap::init( int w, int h, int d, bool bitmap, Optimization optim )
     if ( defaultScreen >= 0 && defaultScreen != x11Screen() ) {
 	QPaintDeviceX11Data* xd = getX11Data( TRUE );
 	xd->x_screen = defaultScreen;
-
-	if ( xd->x_screen == x11AppScreen() ) {
-	    xd->x_depth = QPaintDevice::x11AppDepth();
-	    xd->x_cells = QPaintDevice::x11AppCells();
-	    xd->x_colormap = QPaintDevice::x11AppColormap();
-	    xd->x_defcolormap = QPaintDevice::x11AppDefaultColormap();
-	    xd->x_visual = QPaintDevice::x11AppVisual();
-	    xd->x_defvisual = QPaintDevice::x11AppDefaultVisual();
-	} else {
-	    // not on the default screen, so manually set the x11 data using
-	    // the defaults for this screen
-	    xd->x_depth = DefaultDepth( x11Display(), xd->x_screen );
-	    xd->x_cells = DisplayCells( x11Display(), xd->x_screen );
-	    xd->x_colormap = DefaultColormap( x11Display(), xd->x_screen );
-	    xd->x_defcolormap = FALSE; // ### FIXME 3.1
-	    xd->x_visual =  DefaultVisual( x11Display(), xd->x_screen );
-	    xd->x_defvisual = FALSE; // ### FIXME 3.1
-	}
+	xd->x_depth = QPaintDevice::x11AppDepth( xd->x_screen );
+	xd->x_cells = QPaintDevice::x11AppCells( xd->x_screen );
+	xd->x_colormap = QPaintDevice::x11AppColormap( xd->x_screen );
+	xd->x_defcolormap = QPaintDevice::x11AppDefaultColormap( xd->x_screen );
+	xd->x_visual = QPaintDevice::x11AppVisual( xd->x_screen );
+	xd->x_defvisual = QPaintDevice::x11AppDefaultVisual( xd->x_screen );
 	setX11Data( xd );
     }
 
@@ -334,29 +330,17 @@ void QPixmap::init( int w, int h, int d, bool bitmap, Optimization optim )
     hd = (HANDLE)XCreatePixmap( x11Display(), RootWindow(x11Display(), x11Screen() ),
 				w, h, data->d );
 
-#ifndef QT_NO_XRENDER
-    if (qt_use_xrender) {
-	XRenderPictFormat *format = 0;
-	XRenderPictFormat req;
-	ulong mask = PictFormatType | PictFormatDepth;
-
-	req.type = PictTypeDirect;
-	req.depth = data->d;
-
-	if (data->d == 1) {
-	    req.direct.alpha = 0;
-	    req.direct.alphaMask = 1;
-	    mask |= PictFormatAlpha | PictFormatAlphaMask;
+#ifndef QT_NO_XFTFREETYPE
+    if ( qt_use_xrender && qt_has_xft ) {
+	if ( data->d == 1 ) {
+	    rendhd = (HANDLE) XftDrawCreateBitmap( x11Display(), hd );
 	} else {
-	    format = XRenderFindVisualFormat(x11Display(), (Visual *) x11Visual());
+	    rendhd = (HANDLE) XftDrawCreate( x11Display(), hd,
+					     (Visual *) x11Visual(),
+					     x11Colormap() );
 	}
-
-	if (! format)
-	    format = XRenderFindFormat(x11Display(), mask, &req, 0);
-	if (format)
-	    rendhd = XRenderCreatePicture(x11Display(), hd, format, 0, 0);
     }
-#endif // QT_NO_XRENDER
+#endif // QT_NO_XFTFREETYPE
 
 }
 
@@ -372,12 +356,12 @@ void QPixmap::deref()
 	    XFreeGC( x11Display(), (GC)data->maskgc );
 	if ( qApp && hd) {
 
-#ifndef QT_NO_XRENDER
+#ifndef QT_NO_XFTFREETYPE
 	    if (rendhd) {
-		XRenderFreePicture(x11Display(), rendhd);
+		XftDrawDestroy( (XftDraw *) rendhd );
 		rendhd = 0;
 	    }
-#endif // QT_NO_XRENDER
+#endif // QT_NO_XFTFREETYPE
 
 	    XFreePixmap( x11Display(), hd );
 	    hd = 0;
@@ -416,23 +400,10 @@ QPixmap::QPixmap( int w, int h, const uchar *bits, bool isXbitmap)
 					RootWindow(x11Display(), x11Screen() ),
 					(char *)bits, w, h );
 
-#ifndef QT_NO_XRENDER
-    if (qt_use_xrender) {
-	XRenderPictFormat *format;
-	XRenderPictFormat req;
-
-	req.type = PictTypeDirect;
-	req.depth = 1;
-	req.direct.alpha = 0;
-	req.direct.alphaMask = 1;
-	format = XRenderFindFormat(x11Display(),
-				   (PictFormatType | PictFormatDepth |
-				    PictFormatAlpha | PictFormatAlphaMask),
-				   &req, 0);
-	if (format)
-	    rendhd = (HANDLE) XRenderCreatePicture(x11Display(), hd, format, 0, 0);
-    }
-#endif // QT_NO_XRENDER
+#ifndef QT_NO_XFTFREETYPE
+    if ( qt_use_xrender && qt_has_xft )
+	rendhd = (HANDLE) XftDrawCreateBitmap (x11Display (), hd);
+#endif // QT_NO_XFTFREETYPE
 
     if ( flipped_bits )				// Avoid purify complaint
 	delete [] flipped_bits;
@@ -550,7 +521,7 @@ void QPixmap::fill( const QColor &fillColor )
 	return;
     detach();					// detach other references
     GC gc = qt_xget_temp_gc( x11Screen(), depth()==1 );
-    XSetForeground( x11Display(), gc, fillColor.pixel() );
+    XSetForeground( x11Display(), gc, fillColor.pixel(x11Screen()) );
     XFillRectangle( x11Display(), hd, gc, 0, 0, width(), height() );
 }
 
@@ -576,11 +547,11 @@ int QPixmap::metric( int m ) const
 	switch ( m ) {
 	    case QPaintDeviceMetrics::PdmDpiX:
 	    case QPaintDeviceMetrics::PdmPhysicalDpiX:
-		val = QPaintDevice::x11AppDpiX();
+		val = QPaintDevice::x11AppDpiX( scr );
 		break;
 	    case QPaintDeviceMetrics::PdmDpiY:
 	    case QPaintDeviceMetrics::PdmPhysicalDpiY:
-		val = QPaintDevice::x11AppDpiY();
+		val = QPaintDevice::x11AppDpiY( scr );
 		break;
 	    case QPaintDeviceMetrics::PdmWidthMM:
 		val = (DisplayWidthMM(dpy,scr)*width())/
@@ -623,12 +594,8 @@ int QPixmap::metric( int m ) const
 QImage QPixmap::convertToImage() const
 {
     QImage image;
-    if ( isNull() ) {
-#if defined(QT_CHECK_NULL)
-	qWarning( "QPixmap::convertToImage: Cannot convert a null pixmap" );
-#endif
-	return image;
-    }
+    if ( isNull() )
+	return image; // null image
 
     int	    w  = width();
     int	    h  = height();
@@ -1015,12 +982,12 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
     if ( d == 1 ) {				// 1 bit pixmap (bitmap)
 	if ( hd ) {				// delete old X pixmap
 
-#ifndef QT_NO_XRENDER
+#ifndef QT_NO_XFTFREETYPE
 	    if (rendhd) {
-		XRenderFreePicture(x11Display(), rendhd);
+		XftDrawDestroy( (XftDraw *) rendhd );
 		rendhd = 0;
 	    }
-#endif // QT_NO_XRENDER
+#endif // QT_NO_XFTFREETYPE
 
 	    XFreePixmap( x11Display(), hd );
 	}
@@ -1069,31 +1036,18 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
 					    RootWindow(x11Display(), x11Screen() ),
 					    bits, w, h );
 
-#ifndef QT_NO_XRENDER
-	if (qt_use_xrender) {
-	    XRenderPictFormat *format;
-	    XRenderPictFormat req;
-
-	    req.type = PictTypeDirect;
-	    req.depth = 1;
-	    req.direct.alpha = 0;
-	    req.direct.alphaMask = 1;
-	    format = XRenderFindFormat(x11Display(),
-				       (PictFormatType | PictFormatDepth |
-					PictFormatAlpha | PictFormatAlphaMask),
-				       &req, 0);
-	    if (format)
-		rendhd = (HANDLE) XRenderCreatePicture(x11Display(), hd, format, 0, 0);
-	}
-#endif // QT_NO_XRENDER
+#ifndef QT_NO_XFTFREETYPE
+	if ( qt_use_xrender && qt_has_xft )
+	    rendhd = (HANDLE) XftDrawCreateBitmap( x11Display(), hd );
+#endif // QT_NO_XFTFREETYPE
 
 	if ( tmp_bits )				// Avoid purify complaint
 	    delete [] tmp_bits;
 	data->w = w;  data->h = h;  data->d = 1;
 
-	if ( image.hasAlphaBuffer() ) {
+	if ( img.hasAlphaBuffer() ) {
 	    QBitmap m;
-	    m = image.createAlphaMask( conversion_flags );
+	    m = img.createAlphaMask( conversion_flags );
 	    setMask( m );
 	}
 	return TRUE;
@@ -1152,11 +1106,12 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
       n_bits(green_mask) == gbits &&
        n_bits(blue_mask) == bbits;
 	bool dither_tc =
-	    // Want it
+	    // Want it?
+	    (conversion_flags & Dither_Mask) != ThresholdDither &&
 	    (conversion_flags & DitherMode_Mask) != AvoidDither &&
-	    // Need it
+	    // Need it?
 	    bppc < 24 && !d8 &&
-	    // Contiguous bits?
+	    // Can do it? (Contiguous bits?)
 	    contig_bits;
 
 	static bool init=FALSE;
@@ -1447,7 +1402,7 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
 	px = &pixarr_sorted[0];
 	for ( i=0; i<ncols; i++ ) {		// allocate colors
 	    QColor c( px->r, px->g, px->b );
-	    pix[px->index] = c.pixel();
+	    pix[px->index] = c.pixel(x11Screen());
 	    px++;
 	}
 
@@ -1486,12 +1441,12 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
 
     if ( hd && (width() != w || height() != h || this->depth() != dd) ) {
 
-#ifndef QT_NO_XRENDER
+#ifndef QT_NO_XFTFREETYPE
 	if (rendhd) {
-	    XRenderFreePicture(x11Display(), rendhd);
+	    XftDrawDestroy( (XftDraw *) rendhd );
 	    rendhd = 0;
 	}
-#endif // QT_NO_XRENDER
+#endif // QT_NO_XFTFREETYPE
 
 	XFreePixmap( dpy, hd );			// don't reuse old pixmap
 	hd = 0;
@@ -1501,29 +1456,16 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
 				    RootWindow(x11Display(), x11Screen() ),
 				    w, h, dd );
 
-#ifndef QT_NO_XRENDER
-	if (qt_use_xrender) {
-	    XRenderPictFormat *format = 0;
-	    XRenderPictFormat req;
-	    ulong mask = PictFormatType | PictFormatDepth;
-
-	    req.type = PictTypeDirect;
-	    req.depth = data->d;
-
-	    if (data->d == 1) {
-		req.direct.alpha = 0;
-		req.direct.alphaMask = 1;
-		mask |= PictFormatAlpha | PictFormatAlphaMask;
+#ifndef QT_NO_XFTFREETYPE
+	if ( qt_use_xrender && qt_has_xft ) {
+	    if ( data->d == 1 ) {
+		rendhd = (HANDLE) XftDrawCreateBitmap( x11Display (), hd );
 	    } else {
-		format = XRenderFindVisualFormat(x11Display(), (Visual *) x11Visual());
+		rendhd = (HANDLE) XftDrawCreate( x11Display (), hd,
+						 (Visual *) x11Visual(), x11Colormap() );
 	    }
-
-	    if (! format)
-		format = XRenderFindFormat(x11Display(), mask, &req, 0);
-	    if (format)
-		rendhd = XRenderCreatePicture(x11Display(), hd, format, 0, 0);
 	}
-#endif // QT_NO_XRENDER
+#endif // QT_NO_XFTFREETYPE
 
     }
 
@@ -1545,9 +1487,9 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
 	m = img.createAlphaMask( conversion_flags );
 	setMask( m );
 
-#ifndef QT_NO_XRENDER
+#ifndef QT_NO_XFTFREETYPE
 	// ### only support 32bit images at the moment
-	if (qt_use_xrender && img.depth() == 32) {
+	if (qt_use_xrender && qt_has_xft && img.depth() == 32) {
 	    data->alphapm = new QPixmap; // create a null pixmap
 
 	    // setup pixmap data
@@ -1560,16 +1502,8 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
 		XCreatePixmap(x11Display(), RootWindow(x11Display(), x11Screen()),
 			      w, h, 8);
 
-	    XRenderPictFormat *format = 0;
-	    XRenderPictFormat req;
-	    ulong mask = PictFormatType | PictFormatDepth | PictFormatAlphaMask;
-	    req.type = PictTypeDirect;
-	    req.depth = 8;
-	    req.direct.alphaMask = 0xff;
-	    format = XRenderFindFormat(x11Display(), mask, &req, 0);
-	    if (format)
-		data->alphapm->rendhd =
-		    XRenderCreatePicture(x11Display(), data->alphapm->hd, format, 0, 0);
+	    data->alphapm->rendhd =
+		(HANDLE) XftDrawCreateAlpha( x11Display(), data->alphapm->hd, 8 );
 
 	    XImage *axi = XCreateImage(x11Display(), (Visual *) x11Visual(),
 				       8, ZPixmap, 0, 0, w, h, 8, 0);
@@ -1591,7 +1525,7 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
 		qSafeXDestroyImage(axi);
 	    }
 	}
-#endif // QT_NO_XRENDER
+#endif // QT_NO_XFTFREETYPE
     }
 
     return TRUE;
@@ -1609,7 +1543,7 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
     border of the window. If \a h is negative, the function copies
     everything to the bottom of the window.
 
-    Note that grabWindows() grabs pixels from the screen, not from the
+    Note that grabWindow() grabs pixels from the screen, not from the
     window. If there is another window partially or entirely over the
     one you grab, you get pixels from the overlying window, too.
 
@@ -1622,30 +1556,68 @@ bool QPixmap::convertFromImage( const QImage &img, int conversion_flags )
     \warning Grabbing an area outside the screen is not safe in
     general. This depends on the underlying window system.
 
+    \warning X11 only: If \a window is not the same depth as the root
+    window and another window partially or entirely obscures the one
+    you grab, you will \e not get pixels from the overlying window.
+    The contests of the obscured areas in the pixmap are undefined and
+    uninitialized.
+
     \sa grabWidget()
 */
 
 QPixmap QPixmap::grabWindow( WId window, int x, int y, int w, int h )
 {
+    if ( w == 0 || h == 0 )
+	return QPixmap();
+
     Display *dpy = x11AppDisplay();
-    if ( w <= 0 || h <= 0 ) {
-	if ( w == 0 || h == 0 ) {
-	    QPixmap nullPixmap;
-	    return nullPixmap;
-	}
-	XWindowAttributes a;
-	XGetWindowAttributes( dpy, window, &a );
-	if ( w < 0 )
-	    w = a.width - x;
-	if ( h < 0 )
-	    h = a.height - y;
+    XWindowAttributes window_attr;
+    if ( ! XGetWindowAttributes( dpy, window, &window_attr ) )
+	return QPixmap();
+
+    if ( w < 0 )
+	w = window_attr.width - x;
+    if ( h < 0 )
+	h = window_attr.height - y;
+
+    // determine the screen
+    int scr;
+    for ( scr = 0; scr < ScreenCount( dpy ); ++scr ) {
+	if ( window_attr.root == RootWindow( dpy, scr ) )	// found it
+	    break;
     }
-    QPixmap pm( w, h );				// create new pixmap
+    if ( scr >= ScreenCount( dpy ) )		// sanity check
+	return QPixmap();
+
+
+    // get the depth of the root window
+    XWindowAttributes root_attr;
+    if ( ! XGetWindowAttributes( dpy, window_attr.root, &root_attr ) )
+        return QPixmap();
+
+    if ( window_attr.depth == root_attr.depth ) {
+        // if the depth of the specified window and the root window are the
+        // same, grab pixels from the root window (so that we get the any
+        // overlapping windows and window manager frames)
+
+        // map x and y to the root window
+        WId unused;
+        if ( ! XTranslateCoordinates( dpy, window, window_attr.root, x, y,
+                                      &x, &y, &unused ) )
+            return QPixmap();
+
+       window = window_attr.root;
+    }
+
+    QPixmap pm( w, h );
     pm.data->uninit = FALSE;
-    GC gc = qt_xget_temp_gc( qt_xscreen(), FALSE );
+    pm.x11SetScreen( scr );
+
+    GC gc = qt_xget_temp_gc( scr, FALSE );
     XSetSubwindowMode( dpy, gc, IncludeInferiors );
     XCopyArea( dpy, window, pm.handle(), gc, x, y, w, h, 0, 0 );
     XSetSubwindowMode( dpy, gc, ClipByChildren );
+
     return pm;
 }
 
@@ -1657,6 +1629,10 @@ QPixmap QPixmap::grabWindow( WId window, int x, int y, int w, int h )
     for unwanted translation, i.e. xForm() returns the smallest image
     that contains all the transformed points of the original image.
 
+    This function is slow because it involves transformation to a
+    QImage, non-trivial computations and a transformation back to a
+    QPixmap.
+
     \sa trueMatrix(), QWMatrix, QPainter::setWorldMatrix() QImage::xForm()
 */
 
@@ -1754,7 +1730,7 @@ QPixmap QPixmap::xForm( const QWMatrix &matrix ) const
 	if ( depth1 )				// fill with zeros
 	    memset( dptr, 0, dbytes );
 	else if ( bpp == 8 )			// fill with background color
-	    memset( dptr, Qt::white.pixel(), dbytes );
+	    memset( dptr, Qt::white.pixel( x11Screen() ), dbytes );
 	else
 	    memset( dptr, 0xff, dbytes );
 #if defined(QT_MITSHM)
@@ -1810,7 +1786,7 @@ QPixmap QPixmap::xForm( const QWMatrix &matrix ) const
     }
 
     if ( depth1 ) {				// mono bitmap
-	QPixmap pm( w, h, dptr, TRUE );
+	QPixmap pm( w, h, dptr, QImage::systemBitOrder() != QImage::BigEndian );
 	pm.data->bitmap = data->bitmap;
 	free( dptr );
 	if ( data->mask ) {
@@ -1841,8 +1817,8 @@ QPixmap QPixmap::xForm( const QWMatrix &matrix ) const
 	if ( data->mask ) // xform mask, too
 	    pm.setMask( data->mask->xForm(matrix) );
 
-#ifndef QT_NO_XRENDER
-	if ( qt_use_xrender && data->alphapm ) { // xform the alpha channel
+#ifndef QT_NO_XFTFREETYPE
+	if ( qt_use_xrender && qt_has_xft && data->alphapm ) { // xform the alpha channel
 	    XImage *axi = 0;
 	    if ((axi = XGetImage(x11Display(), data->alphapm->handle(),
 				 0, 0, ws, hs, AllPlanes, ZPixmap))) {
@@ -1874,17 +1850,9 @@ QPixmap QPixmap::xForm( const QWMatrix &matrix ) const
 				      RootWindow(x11Display(), x11Screen()),
 				      w, h, 8);
 
-		    XRenderPictFormat *format = 0;
-		    XRenderPictFormat req;
-		    ulong mask = PictFormatType | PictFormatDepth | PictFormatAlphaMask;
-		    req.type = PictTypeDirect;
-		    req.depth = 8;
-		    req.direct.alphaMask = 0xff;
-		    format = XRenderFindFormat(x11Display(), mask, &req, 0);
-		    if (format)
-			pm.data->alphapm->rendhd =
-			    XRenderCreatePicture(x11Display(), pm.data->alphapm->hd,
-						 format, 0, 0);
+		    pm.data->alphapm->rendhd =
+			(HANDLE) XftDrawCreateAlpha( x11Display(),
+						     pm.data->alphapm->hd, 8 );
 
 		    XImage *axi2 = XCreateImage(x11Display(), (Visual *) x11Visual(),
 						8, ZPixmap, 0, (char *)dptr, w, h, 8, 0);
@@ -1900,7 +1868,7 @@ QPixmap QPixmap::xForm( const QWMatrix &matrix ) const
 		qSafeXDestroyImage(axi);
 	    }
 	}
-#endif
+#endif // QT_NO_XFTFREETYPE
 
 	return pm;
     }
@@ -1931,25 +1899,12 @@ void QPixmap::x11SetScreen( int screen )
     if ( isNull() ) {
 	QPaintDeviceX11Data* xd = getX11Data( TRUE );
 	xd->x_screen = screen;
-
-	if ( xd->x_screen == QPaintDevice::x11AppScreen() ) {
-	    xd->x_depth = QPaintDevice::x11AppDepth();
-	    xd->x_cells = QPaintDevice::x11AppCells();
-	    xd->x_colormap = QPaintDevice::x11AppColormap();
-	    xd->x_defcolormap = QPaintDevice::x11AppDefaultColormap();
-	    xd->x_visual = QPaintDevice::x11AppVisual();
-	    xd->x_defvisual = QPaintDevice::x11AppDefaultVisual();
-	} else {
-	    // not on the default screen, so manually set the x11 data using
-	    // the defaults for this screen
-	    xd->x_depth = DefaultDepth( x11Display(), xd->x_screen );
-	    xd->x_cells = DisplayCells( x11Display(), xd->x_screen );
-	    xd->x_colormap = DefaultColormap( x11Display(), xd->x_screen );
-	    xd->x_defcolormap = FALSE; // ### FIXME 3.1
-	    xd->x_visual =  DefaultVisual( x11Display(), xd->x_screen );
-	    xd->x_defvisual = FALSE; // ### FIXME 3.1
-	}
-
+	xd->x_depth = QPaintDevice::x11AppDepth( screen );
+	xd->x_cells = QPaintDevice::x11AppCells( screen );
+	xd->x_colormap = QPaintDevice::x11AppColormap( screen );
+	xd->x_defcolormap = QPaintDevice::x11AppDefaultColormap( screen );
+	xd->x_visual = QPaintDevice::x11AppVisual( screen );
+	xd->x_defvisual = QPaintDevice::x11AppDefaultVisual( screen );
     	setX11Data( xd );
 	return;
     }
@@ -1961,36 +1916,23 @@ void QPixmap::x11SetScreen( int screen )
     resize(0,0);
     QPaintDeviceX11Data* xd = getX11Data( TRUE );
     xd->x_screen = screen;
-
-    if ( xd->x_screen == QPaintDevice::x11AppScreen() ) {
-	xd->x_depth = QPaintDevice::x11AppDepth();
-	xd->x_cells = QPaintDevice::x11AppCells();
-	xd->x_colormap = QPaintDevice::x11AppColormap();
-	xd->x_defcolormap = QPaintDevice::x11AppDefaultColormap();
-	xd->x_visual = QPaintDevice::x11AppVisual();
-	xd->x_defvisual = QPaintDevice::x11AppDefaultVisual();
-    } else {
-	// not on the default screen, so manually set the x11 data using
-	// the defaults for this screen
-	xd->x_depth = DefaultDepth( x11Display(), xd->x_screen );
-	xd->x_cells = DisplayCells( x11Display(), xd->x_screen );
-	xd->x_colormap = DefaultColormap( x11Display(), xd->x_screen );
-	xd->x_defcolormap = FALSE; // ### FIXME 3.1
-	xd->x_visual =  DefaultVisual( x11Display(), xd->x_screen );
-	xd->x_defvisual = FALSE; // ### FIXME 3.1
-    }
-
+    xd->x_depth = QPaintDevice::x11AppDepth( screen );
+    xd->x_cells = QPaintDevice::x11AppCells( screen );
+    xd->x_colormap = QPaintDevice::x11AppColormap( screen );
+    xd->x_defcolormap = QPaintDevice::x11AppDefaultColormap( screen );
+    xd->x_visual = QPaintDevice::x11AppVisual( screen );
+    xd->x_defvisual = QPaintDevice::x11AppDefaultVisual( screen );
     setX11Data( xd );
     convertFromImage( img );
 }
 
-#ifndef QT_NO_XRENDER
+#ifndef QT_NO_XFTFREETYPE
 
 /*!
   \internal
   helper for blitting alpha data into another pixmap
 */
-void qt_x11_blit_alpha_pixmap(QPixmap *dst, int dx, int dy,
+Q_EXPORT void qt_x11_blit_alpha_pixmap(QPixmap *dst, int dx, int dy,
 			      const QPixmap *src, int sx, int sy,
 			      int sw, int sh)
 {
@@ -2012,17 +1954,9 @@ void qt_x11_blit_alpha_pixmap(QPixmap *dst, int dx, int dy,
 			  RootWindow(dst->x11Display(), dst->x11Screen()),
 			  dst->width(), dst->height(), 8);
 
-	XRenderPictFormat *format = 0;
-	XRenderPictFormat req;
-	ulong mask = PictFormatType | PictFormatDepth | PictFormatAlphaMask;
-	req.type = PictTypeDirect;
-	req.depth = 8;
-	req.direct.alphaMask = 0xff;
-	format = XRenderFindFormat(dst->x11Display(), mask, &req, 0);
-	if (format)
-	    dst->data->alphapm->rendhd =
-		XRenderCreatePicture(dst->x11Display(), dst->data->alphapm->hd,
-				     format, 0, 0);
+	dst->data->alphapm->rendhd =
+	    (Qt::HANDLE) XftDrawCreateAlpha( dst->x11Display(),
+					     dst->data->alphapm->hd, 8 );
     }
 
     if (sw < 0)
@@ -2053,4 +1987,14 @@ void qt_x11_copy_alpha_pixmap(QPixmap *dst, const QPixmap *src)
     qt_x11_blit_alpha_pixmap(dst, 0, 0, src, 0, 0, dst->width(), dst->height());
 }
 
-#endif // !QT_NO_XRENDER
+#endif // !QT_NO_XFTFREETYPE
+
+/*!
+  Returns TRUE if painting with this pixmap might not necessarily
+  paint all pixels in its rectangular area.
+*/
+bool QPixmap::hasAlpha() const
+{
+    return data->alphapm || data->mask;
+}
+
