@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qstyleplugin.cpp   3.0.5   edited Oct 12 2001 $
+** $Id: qt/qstyleplugin.cpp   3.1.2   edited Nov 7 16:55 $
 **
 ** Implementation of QSqlDriverPlugin class
 **
@@ -44,36 +44,41 @@
 #include "qobjectcleanuphandler.h"
 #include "qstyle.h"
 
-/*!   \class QStylePlugin qstyleplugin.h
-  \brief The QStylePlugin class provides an abstract base for custom QStyle plugins.
-  \ingroup plugins
+/*!
+    \class QStylePlugin qstyleplugin.h
+    \brief The QStylePlugin class provides an abstract base for custom QStyle plugins.
 
-  The style plugin is a simple plugin interface that makes it easy to
-  create custom styles that can be loaded dynamically into
-  applications with a QStyleFactory.
+    \ingroup plugins
 
-  Writing a style plugin is achieved by subclassing this base class,
-  reimplementing the pure virtual functions keys() and create(), and
-  exporting the class with the Q_EXPORT_PLUGIN macro.  See the \link
-  plugins-howto.html plugins documentation\endlink for an example.
+    The style plugin is a simple plugin interface that makes it easy
+    to create custom styles that can be loaded dynamically into
+    applications with a QStyleFactory.
+
+    Writing a style plugin is achieved by subclassing this base class,
+    reimplementing the pure virtual functions keys() and create(), and
+    exporting the class with the \c Q_EXPORT_PLUGIN macro. See the
+    \link plugins-howto.html plugins documentation\endlink for an
+    example.
 */
 
-/*! \fn QStringList QStylePlugin::keys() const
+/*!
+    \fn QStringList QStylePlugin::keys() const
 
-  Returns the list of style keys this plugin supports.
+    Returns the list of style keys this plugin supports.
 
-  These keys are usually the class names of the custom styles that are
-  implemented in the plugin.
+    These keys are usually the class names of the custom styles that
+    are implemented in the plugin.
 
-  \sa create()
+    \sa create()
 */
 
-/*! \fn QStyle* QStylePlugin::create( const QString& key )
+/*!
+    \fn QStyle* QStylePlugin::create( const QString& key )
 
-  Creates and returns a QStyle object for the style key \a key. The
-  style key is usually the class name of the required style.
+    Creates and returns a QStyle object for the style key \a key. The
+    style key is usually the class name of the required style.
 
-  \sa keys()
+    \sa keys()
 */
 
 class QStylePluginPrivate : public QStyleFactoryInterface, public QLibraryInterface
@@ -154,8 +159,8 @@ bool QStylePluginPrivate::canUnload() const
 
 
 /*!
-  Constructs a style plugin. This is invoked automatically by
-  the Q_EXPORT_PLUGIN macro.
+    Constructs a style plugin. This is invoked automatically by the
+    \c Q_EXPORT_PLUGIN macro.
 */
 QStylePlugin::QStylePlugin()
     : QGPlugin( (QStyleFactoryInterface*)(d = new QStylePluginPrivate( this )) )
@@ -163,11 +168,10 @@ QStylePlugin::QStylePlugin()
 }
 
 /*!
-  Destroys the style plugin.
-
-  You never have to call this explicitly. Qt destroys a plugin
-  automatically when it is no longer used.
+    Destroys the style plugin.
 
+    You never have to call this explicitly. Qt destroys a plugin
+    automatically when it is no longer used.
 */
 QStylePlugin::~QStylePlugin()
 {
