@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qwidgetstack.h   3.0.5   edited Oct 12 2001 $
+** $Id: qt/qwidgetstack.h   3.1.2   edited Nov 7 16:55 $
 **
 ** Definition of QWidgetStack class
 **
@@ -55,6 +55,7 @@ class Q_EXPORT QWidgetStack: public QFrame
     Q_OBJECT
 public:
     QWidgetStack( QWidget* parent=0, const char* name=0 );
+    QWidgetStack( QWidget* parent, const char* name, WFlags f);
 
     ~QWidgetStack();
 
@@ -88,7 +89,7 @@ protected:
     void childEvent( QChildEvent * );
 
 private:
-    bool isMyChild( QWidget * );
+    void init();
 
     QWidgetStackPrivate * d;
     QIntDict<QWidget> * dict;
